Welcome to Mistral's documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 1

   README <readme>
   Overview <overview>
   quickstart

.. toctree::
   :maxdepth: 2

   dsl/index

.. toctree::
   :maxdepth: 3
   
   developer/index
   

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

